@@ -1,11 +1,11 @@
 import json
 import os
 from copy import deepcopy
-from typing import List, Union
+from typing import Optional, List, Union
 
 from ..common import S3Artifact
 from ..config import config
-from ..executor import Executor, run_script
+from ..executor import Executor, render_script_with_tmp_root, run_script
 from ..io import InputArtifact
 from ..utils import randstr, upload_s3
 
@@ -51,25 +51,25 @@ class DispatcherExecutor(Executor):
     """
 
     def __init__(self,
-                 host: str = None,
-                 queue_name: str = None,
+                 host: Optional[str] = None,
+                 queue_name: Optional[str] = None,
                  port: int = 22,
                  username: str = "root",
-                 password: str = None,
-                 private_key_file: os.PathLike = None,
-                 image: str = None,
-                 image_pull_policy: str = None,
+                 password: Optional[str] = None,
+                 private_key_file: Optional[os.PathLike] = None,
+                 image: Optional[str] = None,
+                 image_pull_policy: Optional[str] = None,
                  command: Union[str, List[str]] = "python3",
                  remote_command: Union[str, List[str]] = None,
                  map_tmp_dir: bool = True,
-                 machine_dict: dict = None,
-                 resources_dict: dict = None,
-                 task_dict: dict = None,
-                 json_file: os.PathLike = None,
-                 docker_executable: str = None,
-                 singularity_executable: str = None,
-                 podman_executable: str = None,
-                 remote_root: str = None,
+                 machine_dict: Optional[dict] = None,
+                 resources_dict: Optional[dict] = None,
+                 task_dict: Optional[dict] = None,
+                 json_file: Optional[os.PathLike] = None,
+                 docker_executable: Optional[str] = None,
+                 singularity_executable: Optional[str] = None,
+                 podman_executable: Optional[str] = None,
+                 remote_root: Optional[str] = None,
                  ) -> None:
         self.host = host
         self.queue_name = queue_name
@@ -189,9 +189,7 @@ class DispatcherExecutor(Executor):
             else self.remote_command
         cmd = ""
         if self.map_tmp_dir:
-            cmd += "if [ \\\"$(head -n 1 script)\\\" != \\\"# modified by "\
-                "dflow\\\" ]; then sed -i \\\"s#/tmp#$(pwd)/tmp#g\\\" script"\
-                "; sed -i \\\"1i # modified by dflow\\\" script; fi && "
+            cmd += "sed -i \\\"s#\\\\$(pwd)#$(pwd)#g\\\" script && "
 
         cmd += run_script(template.image, remote_command,
                           self.docker_executable, self.singularity_executable,
@@ -217,7 +215,11 @@ class DispatcherExecutor(Executor):
         new_template.script += "os.chdir('%s')\n" % self.work_root
         new_template.script += "with open('script', 'w') as f:\n"
         new_template.script += "    f.write(r\"\"\"\n"
-        new_template.script += template.script
+        if self.map_tmp_dir:
+            new_template.script += render_script_with_tmp_root(template,
+                                                               "$(pwd)/tmp")
+        else:
+            new_template.script += template.script
         new_template.script += "\"\"\")\n"
 
         if self.machine_dict["context_type"] == "Bohrium" and "image_name" \
